@@ -246,6 +246,31 @@ namespace Model
     CreateVolumeRequest& WithClientToken(ClientTokenT&& value) { SetClientToken(std::forward<ClientTokenT>(value)); return *this;}
     ///@}
 
+    ///@{
+    /**
+     * <p>Specifies the Amazon EBS Provisioned Rate for Volume Initialization (volume
+     * initialization rate), in MiB/s, at which to download the snapshot blocks from
+     * Amazon S3 to the volume. This is also known as <i>volume initialization</i>.
+     * Specifying a volume initialization rate ensures that the volume is initialized
+     * at a predictable and consistent rate after creation.</p> <p>This parameter is
+     * supported only for volumes created from snapshots. Omit this parameter if:</p>
+     * <ul> <li> <p>You want to create the volume using fast snapshot restore. You must
+     * specify a snapshot that is enabled for fast snapshot restore. In this case, the
+     * volume is fully initialized at creation.</p>  <p>If you specify a snapshot
+     * that is enabled for fast snapshot restore and a volume initialization rate, the
+     * volume will be initialized at the specified rate instead of fast snapshot
+     * restore.</p>  </li> <li> <p>You want to create a volume that is
+     * initialized at the default rate.</p> </li> </ul> <p>For more information, see <a
+     * href="https://docs.aws.amazon.com/ebs/latest/userguide/initalize-volume.html">
+     * Initialize Amazon EBS volumes</a> in the <i>Amazon EC2 User Guide</i>.</p>
+     * <p>Valid range: 100 - 300 MiB/s</p>
+     */
+    inline int GetVolumeInitializationRate() const { return m_volumeInitializationRate; }
+    inline bool VolumeInitializationRateHasBeenSet() const { return m_volumeInitializationRateHasBeenSet; }
+    inline void SetVolumeInitializationRate(int value) { m_volumeInitializationRateHasBeenSet = true; m_volumeInitializationRate = value; }
+    inline CreateVolumeRequest& WithVolumeInitializationRate(int value) { SetVolumeInitializationRate(value); return *this;}
+    ///@}
+
     ///@{
     /**
      * <p>Reserved for internal use.</p>
@@ -308,6 +333,9 @@ namespace Model
     Aws::String m_clientToken;
     bool m_clientTokenHasBeenSet = false;
 
+    int m_volumeInitializationRate{0};
+    bool m_volumeInitializationRateHasBeenSet = false;
+
     OperatorRequest m_operator;
     bool m_operatorHasBeenSet = false;
 
